=======
Credits
=======

Development Lead
----------------

* Earl Patrick Bellinger <earl.bellinger@yale.edu>

Contributors
------------

* Maria Korolik <maria.korolik@yale.edu>
* Andrés Luengo 
* KJ McConnell 
